<?php
class BitKassaV1ApiWrapper
{
    /** @var string BitKassa merchant ID */
    protected $merchantId;

    /** @var string BitKassa secret API key */
    protected $secretApiKey;

    /** @var string BitKassa API endpoint */
    protected $host;

    const STATUS_OPEN = 'open';
    const STATUS_CANCELLED = 'cancelled';
    const STATUS_EXPIRED = 'expired';
    const STATUS_PENDING = 'pending';
    const STATUS_PAID = 'paid';


    public function __construct($merchantId, $secretApiKey)
    {
        $this->merchantId = $merchantId;
        $this->secretApiKey = $secretApiKey;
        $this->host = 'https://www.bitkassa.nl';
    }

    /**
     * Call BitKassa API
     * 
     * @link https://www.bitkassa.nl/en/api/documentation#summary
     * @param String $action
     * @param Object $params
     */
    private function callApi($action, $params)
    {
        $params['action'] = $action;
        $params['merchant_id'] = $this->merchantId;

        // Create JSON and authentication hash
        $jsonData = json_encode($params);
        $t = time();
        $a = hash('sha256', $this->secretApiKey . $jsonData . $t) . $t; 
        $p = base64_encode($jsonData);

        // Use cURL if available (safer)
        if (function_exists('curl_version')) {
            curl_setopt($ch = curl_init(), CURLOPT_URL, "$this->host/api/v1?bk_p=$p&bk_a=$a");
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            $jsonResult = curl_exec($ch);
            curl_close($ch);
        } else {
            $jsonResult = file_get_contents("$this->host/api/v1?bk_p=$p&bk_a=$a");
        }

        // Return result or throw exception on error
        if (!$jsonResult) throw new Exception('Could not connect to BitKassa API');
        $result = json_decode($jsonResult, true);
        if (!$result['success']) die('Error: ' . $result['error']);
        return $result;
    }

    /**
     * Wrapper function to process the POST parameters 
     * 
     * @link https://www.bitkassa.nl/en/api/documentation#php-examples
     * @return object
     */
    public function getParams()
    {
        $p = $_POST['bk_p'];
        $a = $_POST['bk_a'];
        $jsonData = base64_decode($p);

        // verify authentication hash to be sure this request actually came from BitKassa.
        $t = substr($a, 64);
        $verify = hash('sha256', $this->secretApiKey . $jsonData . $t) . $t;
       // if ($a != $verify) throw new Exception('Authentication error');

        return json_decode($jsonData, true);
    }

    /** 
     * Starting a payment
     * 
     * @link https://www.bitkassa.nl/en/api/documentation#start-payment
     * 
     * @param $options
     * @return object
     */
    public function startPayment($options)
    {
        return $this->callApi('start_payment', $options);
    }

    /** 
     * Retrieving the payment status
     *
     * @link https://www.bitkassa.nl/en/api/documentation#retrieve-status
     * 
     * @param $payment_id 
     * @return object
     */
    public function getPaymentStatus($payment_id)
    {
        return $this->callApi('get_payment_status', array("payment_id" => $payment_id));
    }
}
